@@ -17,11 +17,11 @@ sub new {
 }
 
 sub all {
-    my ($self, $params) = @_;
+    my ($self, %params) = @_;
 
     my $req_params = {
         pair => 'btc_jpy',
-        %{$params || {}},
+        %params,
     };
 
     my $res = $self->client->request(
